#
# spec file for package python-lib3to6
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-lib3to6
Version:        202107.1047
Release:        2.9
Summary:        Module to compile Python 3.6+ code to Python 2.7+
License:        MIT
URL:            https://gitlab.com/mbarkhau/lib3to6
Source:         https://files.pythonhosted.org/packages/source/l/lib3to6/lib3to6-%{version}.tar.gz
# PATCH-FIX-UPSTREAM Based on gh#mbarkhau/lib3to6#5
Patch0:         use-pathlib-directly.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-astor
Requires:       python-click
Requires:       python-typing
Requires:       python-wheel
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module astor}
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module typing}
# /SECTION
%python_subpackages

%description
A module to compile Python 3.6+ code to Python 2.7+.

%prep
%autosetup -p1 -n lib3to6-%{version}
sed -i '1{/^#!/d}' src/lib3to6/__main__.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/lib3to6
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Avoid Python 3.8 specific test cases to support Leap 15.x
%pytest -k 'not (fixture7 or fixture17 or fixture53 or fixture54 or fixture55 or fixture56 or fixture57)'

%post
%python_install_alternative lib3to6

%postun
%python_uninstall_alternative lib3to6

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%python_alternative %{_bindir}/lib3to6
%{python_sitelib}/*

%changelog
* Mon Aug  8 2022 Steve Kowalik <steven.kowalik@suse.com>
- Add patch use-pathlib-directly.patch:
  * Stop using pathlib2.
- No longer remove typing from requirements, we install it explicitly.
* Wed Dec  8 2021 pgajdos@suse.com
- version update to 202107.1047
  - Fix type annotations with list arguments
  - Fix type annotations with attribute access
* Wed Apr 28 2021 Markéta Machová <mmachova@suse.com>
- Update to 202101.1045
  * Fixes for Python 3.9 and mypy 0.800
* Sat Oct 10 2020 John Vandenberg <jayvdb@gmail.com>
- Use %%pytest
- Avoid Python 3.8 specific test cases to support Leap 15.x
- Update to v202009.1044
  * per-file opt-in/opt-out `# lib3to6: [enabled|disabled]`
- from v202006.1041
  * Add detection of invalid imports and point to available backports
    Use `install_requires` option to whitelist installed backports
  * Checkers produce better error messages
  * Colouring of diffs when using `lib3to6` cli command
  * Checker for `yield from` syntax depending on target version
  * Checker for `@` operator depending on target version
  * Fix `--target-version` argument is ignored
  * Remove `from __future__ import X` depending on target version
  * Convert Forward Reference Annotations to strings
  * Don't apply keyword only args fixer for target version 3.0+
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Mar 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 202002.32:
  * python 3.8 support
* Sat Apr 20 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Fri Apr 12 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v201902.30
